package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.DanganFile;

import java.util.List;

/**
 * 档案文件Mapper接口
 * 
 * @author ruoyi
 * @date 2022-10-25
 */
public interface DanganFileMapper 
{
    /**
     * 查询档案文件
     * 
     * @param fileId 档案文件ID
     * @return 档案文件
     */
    public DanganFile selectDanganFileById(Long fileId);

    /**
     * 查询档案文件列表
     * 
     * @param danganFile 档案文件
     * @return 档案文件集合
     */
    public List<DanganFile> selectDanganFileList(DanganFile danganFile);

    /**
     * 新增档案文件
     * 
     * @param danganFile 档案文件
     * @return 结果
     */
    public int insertDanganFile(DanganFile danganFile);

    /**
     * 修改档案文件
     * 
     * @param danganFile 档案文件
     * @return 结果
     */
    public int updateDanganFile(DanganFile danganFile);

    /**
     * 删除档案文件
     * 
     * @param fileId 档案文件ID
     * @return 结果
     */
    public int deleteDanganFileById(Long fileId);

    public int deleteFileByDanganId(Long danganId);

    /**
     * 批量删除档案文件
     * 
     * @param fileIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteDanganFileByIds(String[] fileIds);

    public int batchFileInfo(List<DanganFile> list);
}
